Index: code/trunk/src/modules/pickup/PickupManager.h
===================================================================
--- code/trunk/src/modules/pickup/PickupManager.h	(revision 11707)
+++ code/trunk/src/modules/pickup/PickupManager.h	(revision 11708)
@@ -64,6 +64,6 @@
         bool usable; //!< Whether the @ref orxonox::Pickupable "Pickupable" is usable.
         bool unusable; //!< Whether the @ref orxonox::Pickupable "Pickupable" is droppable.
-        uint32_t representationObjectId; //!< The objectId of the @ref orxonox::PickupRepresentation "PickupRepresentation" that represents the @ref orxonox::Pickupable "Pickupable".
         std::string representationName; //!< The name of the associated PickupRepresentation
+        uint32_t carrierPawnId; //!< The objectId of the @ref orxonox::Pawn "Pawn" that carries the @ref orxonox::Pickupable "Pickupable".
     };
     // tolua_end
@@ -120,5 +120,5 @@
             static void pickupChangedUsedNetwork(uint32_t pickup, bool inUse, bool usable, bool unusable); //!< Helper method to react to the change in the used status of a Pickupable.
             virtual void pickupChangedPickedUp(Pickupable* pickup, bool pickedUp) override; //!< Is called by the PickupListener to notify the PickupManager, that the input Pickupable has transited to the input pickedUp state.
-            static void pickupChangedPickedUpNetwork(uint32_t pickup, bool usable, uint32_t representationObjectId, const std::string& representationName, bool pickedUp); //!< Helper method to react to the change in the pickedUp status of a Pickupable.
+            static void pickupChangedPickedUpNetwork(uint32_t pickup, bool usable, const std::string& representationName, bool pickedUp, uint32_t carrierPawnId); //!< Helper method to react to the change in the pickedUp status of a Pickupable.
 
         // Methods to be used by the PickupInventory.
Index: code/trunk/src/modules/pickup/PickupPrereqs.h
===================================================================
--- code/trunk/src/modules/pickup/PickupPrereqs.h	(revision 11707)
+++ code/trunk/src/modules/pickup/PickupPrereqs.h	(revision 11708)
@@ -72,4 +72,5 @@
     class Pickup;
     class PickupCollection;
+    class PickupInventoryContainer;
     class PickupManager;
     class PickupRepresentation;

Index: code/trunk/src/modules/pickup/PickupManager.cc
===================================================================
--- code/trunk/src/modules/pickup/PickupManager.cc	(revision 11707)
+++ code/trunk/src/modules/pickup/PickupManager.cc	(revision 11708)
@@ -301,22 +301,10 @@
         if(GameMode::isStandalone() || Host::getPlayerID() == clientId)
         {
-            // If there is no PickupRepresentation registered the default representation is used.
-            if(this->representations_.find(pickup->getRepresentationName()) == this->representations_.end())
-                PickupManager::pickupChangedPickedUpNetwork(index, pickup->isUsable(), this->defaultRepresentation_->getObjectID(), pickup->getRepresentationName(), pickedUp);
-            else
-                PickupManager::pickupChangedPickedUpNetwork(index, pickup->isUsable(), this->representations_[pickup->getRepresentationName()]->getObjectID(), pickup->getRepresentationName(), pickedUp);
+            PickupManager::pickupChangedPickedUpNetwork(index, pickup->isUsable(), pickup->getRepresentationName(), pickedUp, pawn->getObjectID());
         }
         // If the concerned host is somewhere in the network, we call pickupChangedPickedUpNetwork() on its PickupManager.
         else
         {
-            // If there is no PickupRepresentation registered the default representation is used.
-            if(this->representations_.find(pickup->getRepresentationName()) == this->representations_.end())
-            {
-                callStaticNetworkFunction(&PickupManager::pickupChangedPickedUpNetwork, clientId, index, pickup->isUsable(), this->defaultRepresentation_->getObjectID(), pickedUp);
-            }
-            else
-            {
-                callStaticNetworkFunction(&PickupManager::pickupChangedPickedUpNetwork, clientId, index, pickup->isUsable(), this->representations_[pickup->getRepresentationName()]->getObjectID(), pickedUp);
-            }
+            callStaticNetworkFunction(&PickupManager::pickupChangedPickedUpNetwork, clientId, index, pickup->isUsable(), pickedUp, pawn->getObjectID());
         }
 
@@ -332,12 +320,12 @@
     @param usable
         Whether the Pickupable's used status can be changed to used in the PickupInventory.
-    @param representationObjectId
-        The objectId identifying (over the network) the PickupRepresentation that represents this Pickupable.
     @param representationName
         The name of the associated PickupRepresentation
     @param pickedUp
         The pickedUp status the Pickupable changed to.
-    */
-    /*static*/ void PickupManager::pickupChangedPickedUpNetwork(uint32_t pickup, bool usable, uint32_t representationObjectId, const std::string& representationName, bool pickedUp)
+    @param carrierPawnId
+        The objectId identifier (over the network) the Pawn that carries this Pickupable
+    */
+    /*static*/ void PickupManager::pickupChangedPickedUpNetwork(uint32_t pickup, bool usable, const std::string& representationName, bool pickedUp, uint32_t carrierPawnId)
     {
         PickupManager& manager = PickupManager::getInstance(); // Get the PickupManager singleton on this host.
@@ -352,6 +340,6 @@
             container->usable = usable;
             container->unusable = false;
-            container->representationObjectId = representationObjectId;
             container->representationName = representationName;
+            container->carrierPawnId = carrierPawnId;
             // Insert the container into the pickupInventoryContainers_ list.
             manager.pickupInventoryContainers_.insert(std::pair<uint32_t, PickupInventoryContainer*>(pickup, container));